==> aloe-1.3.tar.gz: aloe-1.3/modules/utran_turbocoder/src/module_imp.c <==
/** ALOE headers
 */
#include <phal_sw_api.h>
#include <math.h>
#include <swapi_utils.h>

#include "turbocoder.h"

#include "typetools.h"

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"



int longblock,numblocks;
int configured;

char input_bits[INPUT_MAX_DATA*8];

int process_input(int len)
{
    int l;
    char *wptr;
    int rpm,wpm;

    /* if working without control interface, set blocklenght to received packet length */
    if (!configured) {
        numblocks = DIVINT(8*len,MAX_LONG_CB);
        longblock = 8*len/numblocks;
    }

    if (len!=typeSizeArray(TYPE_BITSTREAM,longblock*numblocks)) {
        Log("TurboCoder: Invalid input length: longblock %d numblocks %d len %d\n",longblock,numblocks,len);
        return 0;
    }

    bin2char(input_data,input_bits,longblock*numblocks);

    wptr=input_data;
    rpm=0;
    wpm=0;
    for (l=0;l<numblocks;l++) {
        TurboCoder(&input_bits[rpm],wptr,longblock);
        wptr+=RATE*longblock+TOTALTAIL;
        wpm+=RATE*longblock+TOTALTAIL;
        rpm+=longblock;
    }

    char2bin(input_data,output_data,wpm);
    
    /* send throught output */
    SendItf(0,typeSizeArray(TYPE_BITSTREAM,wpm));

    return 1;
}

int process_control(int len) {
   configured=1;
    longblock=ctrlpkt.long_block;
    numblocks=ctrlpkt.num_blocks;
    Log("TurboCoder: longblock=%d numblocks=%d\n",longblock,numblocks);
}

/** Run function.
 * @return 1 if ok, 0 if error
 */
int RunCustom()
{
    return 1;
}

int InitCustom()
{
    configured=0;
    longblock=0;
    numblocks=0;
    return 1;
}


void ConfigInterfaces(){}

==> aloe-1.4.tar.gz: aloe-1.4/modules/utran_turbocoder/src/module_imp.c <==
/** ALOE headers
 */
#include <phal_sw_api.h>
#include <math.h>
#include <swapi_utils.h>

#include "turbocoder.h"

#include "typetools.h"

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"



int longblock,numblocks;
int configured;

char input_bits[INPUT_MAX_DATA*8];

int process_input(int len)
{
    int l;
    char *wptr;
    int rpm,wpm;

    /* if working without control interface, set blocklenght to received packet length */
    if (!configured) {
        numblocks = DIVINT(8*len,MAX_LONG_CB);
        longblock = (8*len-12)/numblocks;
    }

    if (len<typeSizeArray(TYPE_BITSTREAM,longblock*numblocks)) {
        Log("TurboCoder: Invalid input length: longblock %d numblocks %d len %d\n",longblock,numblocks,len);
        return 0;
    }

    bin2char(input_data,input_bits,longblock*numblocks);

    wptr=input_data;
    rpm=0;
    wpm=0;
    for (l=0;l<numblocks;l++) {
        TurboCoder(&input_bits[rpm],wptr,longblock);
        wptr+=RATE*longblock+TOTALTAIL;
        wpm+=RATE*longblock+TOTALTAIL;
        rpm+=longblock;
    }

    char2bin(input_data,output_data,wpm);
    
    /* send throught output */
    SendItf(0,typeSizeArray(TYPE_BITSTREAM,wpm));

    return 1;
}

int process_control(int len) {
   configured=1;
    longblock=ctrlpkt.long_block;
    numblocks=ctrlpkt.num_blocks;
    Log("TurboCoder: longblock=%d numblocks=%d\n",longblock,numblocks);
}

/** Run function.
 * @return 1 if ok, 0 if error
 */
int RunCustom()
{
    return 1;
}

int InitCustom()
{
    configured=0;
    longblock=0;
    numblocks=0;
    return 1;
}


void ConfigInterfaces(){}
